raffle.generator Module
=======================

This is a simulated module that holds the following class:

- :class:`raffle.Generator()`

This class cannot be directly accessed, but the two user-facing classes within it can be.
Within this class, there exist two directly accessible sub-classes:

- :class:`raffle.generator.stoichiometry_array()`
- :class:`raffle.generator.raffle_generator()`

The documentation for these can be found here: :doc:`raffle.generator_class`.

Finally, the :class:`raffle.generator.raffle_generator()` contains instances of the following classes:

- :class:`raffle.Raffle__Distribs_Container()` - raffle.generator.raffle_generator().distributions
- :class:`raffle.Geom_Rw().basis()` - raffle.generator.raffle_generator().host
- :class:`raffle.Geom_Rw().basis_arary()` - raffle.generator.raffle_generator().structures



.. automodule:: raffle.generator
   :members:
   :undoc-members:
   :show-inheritance:
